==> adafruit_circuitpython_mpu6050-1.3.2.tar.gz: adafruit_circuitpython_mpu6050-1.3.2/examples/mpu6050_displayio_simpletest.py <==
# SPDX-FileCopyrightText: 2024 Tim Cocks for Adafruit Industries
# SPDX-FileCopyrightText: 2024 Jose D. Montoya
#
# SPDX-License-Identifier: MIT

import time
import board
from adafruit_display_text.bitmap_label import Label
from terminalio import FONT
from displayio import Group
import adafruit_mpu6050

# Simple demo of using the built-in display.
# create a main_group to hold anything we want to show on the display.
main_group = Group()
# Initialize I2C bus and sensor.
i2c = board.I2C()  # uses board.SCL and board.SDA
mpu = adafruit_mpu6050.MPU6050(i2c)


# Create Label(s) to show the readings. If you have a very small
# display you may need to change to scale=1.
display_output_acceleration = Label(FONT, text="", scale=1)
display_output_gyro = Label(FONT, text="", scale=1)
display_output_temperature = Label(FONT, text="", scale=1)

# place the label(s) in the middle of the screen with anchored positioning
display_output_acceleration.anchor_point = (0, 0)
display_output_acceleration.anchored_position = (
    4,
    board.DISPLAY.height // 2 - 60,
)
display_output_gyro.anchor_point = (0, 0)
display_output_gyro.anchored_position = (
    4,
    board.DISPLAY.height // 2 - 40,
)
display_output_temperature.anchor_point = (0, 0)
display_output_temperature.anchored_position = (
    4,
    board.DISPLAY.height // 2 - 20,
)


# add the label(s) to the main_group
main_group.append(display_output_acceleration)
main_group.append(display_output_gyro)
main_group.append(display_output_temperature)

# set the main_group as the root_group of the built-in DISPLAY
board.DISPLAY.root_group = main_group

# begin main loop
while True:
    # update the text of the label(s) to show the sensor readings
    accx, accy, accz = mpu.acceleration
    gyro_x, gyro_y, gyro_z = mpu.gyro
    display_output_acceleration.text = (
        f"Acc X:{accx:.1f} Y:{accy:.1f} Z:{accz:.1f} m/s^2"
    )
    display_output_gyro.text = (
        f"Gyro X:{gyro_x:.1f} Y:{gyro_y:.1f} Z:{gyro_z:.1f} rad/s"
    )
    display_output_temperature.text = f"Temp: {mpu.temperature:.1f} C"
    # wait for a bit
    time.sleep(0.5)

==> adafruit_circuitpython_mpu6050-1.3.3.tar.gz: adafruit_circuitpython_mpu6050-1.3.3/examples/mpu6050_displayio_simpletest.py <==
# SPDX-FileCopyrightText: 2024 Tim Cocks for Adafruit Industries
# SPDX-FileCopyrightText: 2024 Jose D. Montoya
#
# SPDX-License-Identifier: MIT

import time

import board
from adafruit_display_text.bitmap_label import Label
from displayio import Group
from terminalio import FONT

import adafruit_mpu6050

# Simple demo of using the built-in display.
# create a main_group to hold anything we want to show on the display.
main_group = Group()
# Initialize I2C bus and sensor.
i2c = board.I2C()  # uses board.SCL and board.SDA
mpu = adafruit_mpu6050.MPU6050(i2c)


# Create Label(s) to show the readings. If you have a very small
# display you may need to change to scale=1.
display_output_acceleration = Label(FONT, text="", scale=1)
display_output_gyro = Label(FONT, text="", scale=1)
display_output_temperature = Label(FONT, text="", scale=1)

# place the label(s) in the middle of the screen with anchored positioning
display_output_acceleration.anchor_point = (0, 0)
display_output_acceleration.anchored_position = (
    4,
    board.DISPLAY.height // 2 - 60,
)
display_output_gyro.anchor_point = (0, 0)
display_output_gyro.anchored_position = (
    4,
    board.DISPLAY.height // 2 - 40,
)
display_output_temperature.anchor_point = (0, 0)
display_output_temperature.anchored_position = (
    4,
    board.DISPLAY.height // 2 - 20,
)


# add the label(s) to the main_group
main_group.append(display_output_acceleration)
main_group.append(display_output_gyro)
main_group.append(display_output_temperature)

# set the main_group as the root_group of the built-in DISPLAY
board.DISPLAY.root_group = main_group

# begin main loop
while True:
    # update the text of the label(s) to show the sensor readings
    accx, accy, accz = mpu.acceleration
    gyro_x, gyro_y, gyro_z = mpu.gyro
    display_output_acceleration.text = f"Acc X:{accx:.1f} Y:{accy:.1f} Z:{accz:.1f} m/s^2"
    display_output_gyro.text = f"Gyro X:{gyro_x:.1f} Y:{gyro_y:.1f} Z:{gyro_z:.1f} rad/s"
    display_output_temperature.text = f"Temp: {mpu.temperature:.1f} C"
    # wait for a bit
    time.sleep(0.5)
